.. _telescope_description:

.. currentmodule:: ctapipe.instrument

Telescope Description
=====================

The `TelescopeDescription` class holds info about a complete telescope,
namely it's `OpticsDescription` and `CameraDescription` (though other aspects
may be added)


